/*
 Copyright (c) 2010 by arms22 (arms22 at gmail.com)
 Microchip 23x256 SPI SRAM library for Arduino

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

#include <Arduino.h>
#include <SPI.h>

#include "SPISRAM.h"

SPISRAM::SPISRAM(const byte csPin, const byte addr_width) :
		_csPin(csPin), _addrbus(addr_width) {
}

void SPISRAM::setSPIMode(void)
{
	SPI.setBitOrder(MSBFIRST);
	SPI.setClockDivider(SPI_CLOCK_DIV4);
	SPI.setDataMode(SPI_MODE0);
	SPI.begin();
}

void SPISRAM::init()
{
	pinMode(_csPin, OUTPUT);
	csHigh();
	setSPIMode();
	select();
	writeStatusRegister(SEQ_MODE);
	deselect();
}

byte SPISRAM::read(const uint32 address)
{
	select();
	set_access(READ, address);
	byte data = SPI.transfer(0);
	deselect();
	return data;
}

void SPISRAM::read(const uint32 address, byte *buffer, const uint32 size)
{
	select();
	set_access(READ, address);
	for (uint32 i = 0; i < size; i++)
		*buffer++ = SPI.transfer(0);
	deselect();
}

void SPISRAM::write(const uint32 address, byte data)
{
	select();
	set_access(WRITE, address);
	SPI.write(data);
	deselect();
}

void SPISRAM::write(const uint32 address, byte *buffer, const uint32 size)
{
	select();
	set_access(WRITE, address);
	for (uint32 i = 0; i < size; i++)
		SPI.write(*buffer++);
	deselect();
}
